@@ -22,7 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-__version__ = "2.2.2"
+__version__ = "2.3.0"
 
 from .abc import BasePlayer, BaseClan
 from .clans import RankedClan, Clan
@@ -35,7 +35,7 @@ from .enums import (
     ACHIEVEMENT_ORDER,
     BUILDER_TROOPS_ORDER,
     HERO_ORDER,
-    HERO_PETS_ORDER,
+    PETS_ORDER,
     HOME_TROOP_ORDER,
     SIEGE_MACHINE_ORDER,
     SPELL_ORDER,
@@ -66,7 +66,9 @@ from .iterators import (
 from .miscmodels import (
     Achievement,
     Badge,
+    CapitalDistrict,
     Icon,
+    GoldPassSeason,
     League,
     LegendStatistics,
     LoadGameData,
@@ -78,6 +80,7 @@ from .miscmodels import (
 )
 from .players import Player, ClanMember, RankedPlayer
 from .player_clan import PlayerClan
+from .raid import RaidClan, RaidMember, RaidLogEntry, RaidDistrict, RaidAttack
 from .spell import Spell
 from .troop import Troop
 from .war_clans import WarClan, ClanWarLeagueClan
