@@ -120,7 +120,7 @@ class Client:
         Defaults to ``True``.
 
     connector : :class:`aiohttp.BaseConnector`
-        The aiohttp connector to use. By default this is ``None``.
+        The aiohttp connector to use. By default, this is ``None``.
 
     timeout: :class:`float`
         The number of seconds before timing out with an API query. Defaults to 30.
@@ -137,6 +137,12 @@ class Client:
         special flags that will only be interpreted by coc.py if you set this
         bool to True.
 
+    raw_attribute: :class:`bool`
+        The option to enable the _raw_data attribute for most objects in the library. This attribute will contain
+        the original json data as returned by the API. This can be useful if you want to store a response in a database
+        for later use or are interested in new things that coc.py does not support otherwise yet. But because this
+        increases the memory footprint and is not needed for most use cases, this defaults to ``False``.
+
     Attributes
     ----------
     loop : :class:`asyncio.AbstractEventLoop`
@@ -156,6 +162,7 @@ class Client:
         "stats_max_size",
         "http",
         "realtime",
+        "raw_attribute",
         "_ready",
         "correct_tags",
         "load_game_data",
@@ -184,7 +191,8 @@ class Client:
         stats_max_size: int = 1000,
         load_game_data: LoadGameData = LoadGameData(default=True),
         realtime=False,
-        **_,
+        raw_attribute=False,
+        **kwargs,
     ):
 
         self.loop = loop or asyncio.get_event_loop()
@@ -205,7 +213,7 @@ class Client:
 
         self.http = None  # set in method login()
         self.realtime = realtime
-
+        self.raw_attribute = raw_attribute
         self.correct_tags = correct_tags
         self.load_game_data = load_game_data
 
@@ -249,10 +257,13 @@ class Client:
         for supercell_name, data in buildings.items():
             if supercell_name == "Laboratory":
                 lab_to_townhall = {index: th_level for index, th_level in enumerate(data["TownHallLevel"], start=1)}
+                # there are troops with no lab ...
+                lab_to_townhall[-1] = 1
+                lab_to_townhall[0] = 2
                 break
         else:
             # if the files failed to load, fallback to the old formula of lab level = TH level - 2
-            lab_to_townhall = {i: i + 2 for i in range(1, 15)}
+            lab_to_townhall = {i-2: i for i in range(1, 15)}
 
         for holder in (self._troop_holder, self._spell_holder, self._hero_holder, self._pet_holder):
             holder._load_json(object_ids, english_aliases, lab_to_townhall)
@@ -269,8 +280,6 @@ class Client:
     async def login(self, email: str, password: str) -> None:
         """Retrieves all keys and creates an HTTP connection ready for use.
 
-        @Deprecated
-
         Parameters
         ----------
         email : str
@@ -289,11 +298,19 @@ class Client:
         LOG.debug("HTTP connection created. Client is ready for use.")
 
     def login_with_keys(self, *keys: str) -> None:
-        """Retrieves all keys and creates an HTTP connection ready for use.
+        """Creates an HTTP connection ready for use with the keys you provide.
+
+        .. deprecated:: v2.3.0
+            This function has been deemed deprecated to allow
+            asyncio to clean up the async structures. Please use :func:`Client.login_with_tokens`
+            instead.
 
         Parameters
         ----------
-        keys
+        keys: list[str]
+            Keys or tokens as found from https://developer.clashofclans.com.
+
+
         """
         self.http = http = self._create_client(None, None)
         http._keys = keys
@@ -304,6 +321,23 @@ class Client:
 
         LOG.debug("HTTP connection created. Client is ready for use.")
 
+    async def login_with_tokens(self, *tokens: str) -> None:
+        """Creates an HTTP connection ready for use with the tokens you provide.
+
+        Parameters
+        ----------
+        tokens: list[str]
+            Tokens as found from https://developer.clashofclans.com under "My account" -> <your key> -> "token".
+        """
+        self.http = http = self._create_client(None, None)
+        http._keys = tokens
+        http.keys = cycle(http._keys)
+        http.key_count = len(tokens)
+        await http.create_session(self.connector, self.timeout)
+        self._create_holders()
+
+        LOG.debug("HTTP connection created. Client is ready for use.")
+
     async def close(self) -> None:
         """Closes the HTTP connection from within a loop function such as
         async def main()"""
