@@ -26,15 +26,16 @@ import logging
 import traceback
 
 from collections.abc import Iterable
-from datetime import datetime
+from datetime import datetime, timedelta
 
+import coc.raid
 from .client import Client
 from .clans import Clan
 from .enums import WarRound
 from .players import Player
 from .wars import ClanWar
 from .errors import Maintenance, PrivateWarLog
-from .utils import correct_tag, get_season_end
+from .utils import correct_tag, get_season_end, get_clan_games_start, get_clan_games_end
 
 LOG = logging.getLogger(__name__)
 DEFAULT_SLEEP = 10
@@ -349,6 +350,19 @@ class WarEvents:
 
         return _ValidateEvent.shortcut_register(wrapped, tags, custom_class, retry_interval, WarEvents.event_type)
 
+    @classmethod
+    def new_war(cls, tags=None, custom_class=None, retry_interval=None):
+        """Alias for the preparation start time changes, which is equal to a new war started"""
+
+        async def wrapped(cached_war: ClanWar, war: ClanWar, callback):
+            if cached_war.preparation_start_time and war.preparation_start_time \
+                    and cached_war.preparation_start_time.timestamp != war.preparation_start_time.time:
+                await callback(war)
+            elif war.preparation_start_time and not cached_war.preparation_start_time:
+                # no war on endpoint, so new war is for sure new
+                await callback(war)
+        return _ValidateEvent.shortcut_register(wrapped, tags, custom_class, retry_interval, WarEvents.event_type)
+
 
 @_ValidateEvent
 class ClientEvents:
@@ -404,7 +418,9 @@ class EventsClient(Client):
             "player": self.loop.create_task(self._player_updater()),
             "war": self.loop.create_task(self._war_updater()),
             "maintenance": self.loop.create_task(self._maintenance_poller()),
-            "season": self.loop.create_task(self._end_of_season_poller())
+            "season": self.loop.create_task(self._end_of_season_poller()),
+            "raid_weekend": self.loop.create_task(self._raid_poller()),
+            "clan_games": self.loop.create_task(self._clan_games_poller())
         }
 
         for task in self._updater_tasks.values():
@@ -765,6 +781,34 @@ class EventsClient(Client):
             self._updater_tasks[name] = self.loop.create_task(lookup[name]())
             self._updater_tasks[name].add_done_callback(self._task_callback_check)
 
+    async def _raid_poller(self):
+        # pylint: disable=broad-except, protected-access
+        try:
+            age = 0
+            while self.loop.is_running():
+                try:
+                    [raid_log_entry] = await self.get_raidlog("#2PP", limit=1)
+                    raid_log_entry: coc.raid.RaidLogEntry
+                except Maintenance:
+                    await asyncio.sleep(15)
+                except Exception:
+                    await asyncio.sleep(DEFAULT_SLEEP)
+                else:
+                    if raid_log_entry.start_time.seconds_until + age > 0 and raid_log_entry.end_time.seconds_until > 0:
+                        # raid started
+                        self.dispatch("raid_weekend_start")
+                    elif raid_log_entry.end_time.seconds_until + age > 0 > raid_log_entry.end_time.seconds_until:
+                        # raid ended
+                        self.dispatch("raid_weekend_end")
+                    # sleep for response_retry + 1
+                    age = raid_log_entry._response_retry + 1
+                    await asyncio.sleep(age)
+        except asyncio.CancelledError:
+            pass
+        except (Exception, BaseException) as exception:
+            self.dispatch("event_error", exception)
+            return await self._raid_poller()
+
     async def _end_of_season_poller(self):
         try:
             while self.loop.is_running():
@@ -778,6 +822,26 @@ class EventsClient(Client):
             self.dispatch("event_error", exception)
             return await self._end_of_season_poller()
 
+    async def _clan_games_poller(self):
+        try:
+            while self.loop.is_running():
+                clan_games_start = get_clan_games_start()
+                clan_games_end = get_clan_games_end()
+                now = datetime.utcnow()
+                if now < clan_games_start:
+                    event = "clan_games_start"
+                    mute_time = clan_games_start - now
+                else:
+                    event = "clan_games_end"
+                    mute_time = clan_games_end - now
+                await asyncio.sleep(mute_time.total_seconds())
+                self.dispatch(event)
+        except asyncio.CancelledError:
+            pass
+        except (Exception, BaseException) as exception:
+            self.dispatch("event_error", exception)
+            return await self._end_of_season_poller()
+
     async def _maintenance_poller(self):
         # pylint: disable=broad-except, protected-access
         maintenance_start = None
