@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-import typing
+from typing import Optional, List, TYPE_CHECKING
 
 
 from .miscmodels import try_enum, Achievement, Label, League, LegendStatistics
@@ -35,7 +35,7 @@ from .enums import (
     UNRANKED_LEAGUE_DATA,
     ACHIEVEMENT_ORDER,
     SUPER_TROOP_ORDER,
-    HERO_PETS_ORDER,
+    PETS_ORDER,
 )
 from .abc import BasePlayer
 from .hero import Hero, Pet
@@ -45,7 +45,7 @@ from .troop import Troop
 from .utils import cached_property
 
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
     # pylint: disable=cyclic-import
     from .clans import Clan  # noqa
 
@@ -77,6 +77,8 @@ class ClanMember(BasePlayer):
         The member's rank before the last leaderboard change
         (ie if Bob overtakes Jim in trophies, and they switch ranks on the leaderboard,
         and you want to find out their previous rankings, this will help.).
+    versus_rank: :class:`int`
+        The member's rank in the clan based on versus trophies.
     donations: :class:`int`
         The member's donation count for this season.
     received: :class:`int`
@@ -99,6 +101,7 @@ class ClanMember(BasePlayer):
         "versus_trophies",
         "clan_rank",
         "clan_previous_rank",
+        "versus_rank",
         "donations",
         "received",
         "clan_cls",
@@ -122,6 +125,7 @@ class ClanMember(BasePlayer):
         self.versus_trophies: int = data_get("versusTrophies")
         self.clan_rank: int = data_get("clanRank")
         self.clan_previous_rank: int = data_get("previousClanRank")
+        self.versus_rank: int = data.get("versusRank")
         self.donations: int = data_get("donations")
         self.received: int = data_get("donationsReceived")
 
@@ -129,8 +133,8 @@ class ClanMember(BasePlayer):
         self.league = try_enum(self.league_cls, data=data_get("league") or UNRANKED_LEAGUE_DATA, client=self._client)
         self.role = data_get("role") and Role(value=data["role"])
 
-    async def get_detailed_clan(self) -> typing.Optional["Clan"]:
-        """Get detailed clan details for the player's clan. If the player's clan is ``None``,this will return ``None``.
+    async def get_detailed_clan(self) -> Optional["Clan"]:
+        """Get clan details for the player's clan. If the player's clan is ``None``,this will return ``None``.
 
         Example
         ---------
@@ -181,7 +185,7 @@ class Player(ClanMember):
     Attributes
     ----------
     achievement_cls: :class:`Achievement`
-        The constructor used to create the :attr:`Player.achievements` list. This must inherit :class:`Achievement`.
+        The constructor used to create the :attr:`Player.achievements` list. This must inherit from :class:`Achievement`.
     hero_cls: :class:`Hero`
         The constructor used to create the :attr:`Player.heroes` list. This must inherit from :class:`Hero`.
     label_cls: :class:`Label`
@@ -233,6 +237,7 @@ class Player(ClanMember):
         "war_opted_in",
         "_achievements",
         "_heroes",
+        "_pets",
         "_labels",
         "_spells",
         "_home_troops",
@@ -258,7 +263,7 @@ class Player(ClanMember):
         "_cs_home_troops",
         "_cs_builder_troops",
         "_cs_siege_machines",
-        "_cs_hero_pets",
+        "_cs_pets",
         "_cs_super_troops",
         "_cs_heroes",
         "_cs_spells",
@@ -271,12 +276,13 @@ class Player(ClanMember):
     def __init__(self, *, data, client, load_game_data=None, **_):
         self._client = client
 
-        self._achievements = None  # type: typing.Optional[dict]
-        self._heroes = None  # type: typing.Optional[dict]
-        self._spells = None  # type: typing.Optional[dict]
+        self._achievements = None  # type: Optional[dict]
+        self._heroes = None  # type: Optional[dict]
+        self._spells = None  # type: Optional[dict]
         self._home_troops: dict = {}
         self._builder_troops: dict = {}
         self._super_troops: list = []
+        self._pets = None # type: Optional[dict]
 
         self.achievement_cls = Achievement
         self.hero_cls = Hero
@@ -316,10 +322,10 @@ class Player(ClanMember):
         self.legend_statistics = try_enum(LegendStatistics, data=data_get("legendStatistics"))
 
         try:
-            self.war_opted_in: typing.Optional[bool] = True if data["warPreference"] == "in" else False
+            self.war_opted_in: Optional[bool] = True if data["warPreference"] == "in" else False
         except KeyError:
             # not in a clan / war preference not there
-            self.war_opted_in: typing.Optional[bool] = None
+            self.war_opted_in: Optional[bool] = None
 
         label_cls = self.label_cls
         achievement_cls = self.achievement_cls
@@ -331,7 +337,7 @@ class Player(ClanMember):
         if self._game_files_loaded:
             pet_lookup = [p.name for p in self._client._pet_holder.items]
         else:
-            pet_lookup = HERO_PETS_ORDER
+            pet_lookup = PETS_ORDER
 
         self._iter_labels = (label_cls(data=ldata, client=self._client) for ldata in data_get("labels", []))
         self._iter_achievements = (achievement_cls(data=adata) for adata in data_get("achievements", []))
@@ -396,11 +402,12 @@ class Player(ClanMember):
         # if self._game_files_loaded:
         #     return True
 
-        holders = (self._client._troop_holder, self._client._hero_holder, self._client._spell_holder)
+        holders = (self._client._troop_holder, self._client._hero_holder, self._client._spell_holder,
+                   self._client._pet_holder)
         if not all(holder.loaded for holder in holders):
             self._client._load_holders()
 
-        for items, holder in zip((self.troops, self.heroes, self.spells), holders):
+        for items, holder in zip((self.troops, self.heroes, self.spells, self.pets), holders):
             for item in items:
                 if not item.is_loaded:
                     if isinstance(item, Troop):
@@ -410,12 +417,12 @@ class Player(ClanMember):
                         item._load_from_parent(holder.get(item.name))
 
     @cached_property("_cs_labels")
-    def labels(self) -> typing.List[Label]:
-        """List[:class:`Label`]: A :class:`List` of :class:`Label` that the player has."""
+    def labels(self) -> List[Label]:
+        """List[:class:`Label`]: A :class:`List` of :class:`Label`s that the player has."""
         return list(self._iter_labels)
 
     @cached_property("_cs_achievements")
-    def achievements(self) -> typing.List[Achievement]:
+    def achievements(self) -> List[Achievement]:
         """List[:class:`Achievement`]: A list of the player's achievements."""
         # at the time of writing, the API presents achievements in the order
         # added to the game which doesn't match in-game order.
@@ -430,8 +437,8 @@ class Player(ClanMember):
         self._achievements = sorted_achievements
         return list(sorted_achievements.values())
 
-    def get_achievement(self, name: str, default_value=None) -> typing.Optional[Achievement]:
-        """Returns an achievement with the given name.
+    def get_achievement(self, name: str, default_value=None) -> Optional[Achievement]:
+        """Gets an achievement with the given name.
 
         Parameters
         -----------
@@ -443,7 +450,7 @@ class Player(ClanMember):
         Returns
         --------
         Optional[:class:`Achievement`]
-            The returned achievement or the ``default_value`` if not found, which defaults to ``None``..
+            The returned achievement or the ``default_value`` if not found, which defaults to ``None``.
         """
         if not self._achievements:
             _ = self.achievements
@@ -454,7 +461,7 @@ class Player(ClanMember):
             return default_value
 
     @cached_property("_cs_troops")
-    def troops(self) -> typing.List[Troop]:
+    def troops(self) -> List[Troop]:
         """List[:class:`Troop`]: A :class:`List` of the player's :class:`Troop`.
 
         Troops are **not** ordered in this attribute. Use either :attr:`Player.home_troops`
@@ -493,7 +500,7 @@ class Player(ClanMember):
         return troops
 
     @cached_property("_cs_home_troops")
-    def home_troops(self) -> typing.List[Troop]:
+    def home_troops(self) -> List[Troop]:
         """List[:class:`Troop`]: A :class:`List` of the player's home-base :class:`Troop`.
 
         This will return troops in the order found in both barracks and labatory in-game.
@@ -512,7 +519,7 @@ class Player(ClanMember):
         return list(sorted(self._home_troops.values(), key=lambda t: order.get(t.name, 0)))
 
     @cached_property("_cs_builder_troops")
-    def builder_troops(self) -> typing.List[Troop]:
+    def builder_troops(self) -> List[Troop]:
         """List[:class:`Troop`]: A :class:`List` of the player's builder-base :class:`Troop`.
 
         This will return troops in the order found in both barracks and labatory in-game.
@@ -528,7 +535,7 @@ class Player(ClanMember):
         return list(sorted(self._builder_troops.values(), key=lambda t: order.get(t.name, 0)))
 
     @cached_property("_cs_siege_machines")
-    def siege_machines(self) -> typing.List[Troop]:
+    def siege_machines(self) -> List[Troop]:
         """List[:class:`Troop`]: A :class:`List` of the player's siege-machine :class:`Troop`.
 
         This will return siege machines in the order found in both barracks and labatory in-game.
@@ -540,20 +547,44 @@ class Player(ClanMember):
         troops = (t for t in self.troops if t.name in SIEGE_MACHINE_ORDER or t.is_siege_machine)
         return list(sorted(troops, key=lambda t: order.get(t.name, 0)))
 
-    @cached_property("_cs_hero_pets")
-    def hero_pets(self) -> typing.List[Troop]:
-        """List[:class:`Troop`]: A :class:`List` of the player's hero pets.
+    @cached_property("_cs_pets")
+    def pets(self) -> List[Pet]:
+        """List[:class:`Pet`]: A :class:`List` of the player's hero pets.
 
         This will return hero pets in the order found in the Pet House in-game.
 
         This includes:
         - Hero pets only.
         """
-        order = {k: v for v, k in enumerate(HERO_PETS_ORDER)}
+        order = {k: v for v, k in enumerate(PETS_ORDER)}
         return list(sorted(self._iter_pets, key=lambda t: order.get(t.name, 0)))
 
+    def get_pet(self, name: str, default_value=None) -> Optional[Pet]:
+        """Gets the pet with the given name.
+
+        Parameters
+        -----------
+        name: :class:`str`
+            The name of a pet as found in-game.
+        default_value:
+            The default value to return if a pet with ``name`` is not found. Defaults to ``None``.
+
+        Returns
+        --------
+        Optional[:class:`Pet`]
+            The returned pet or the ``default_value`` if not found, which defaults to ``None``.
+
+        """
+        if not self._pets:
+            _ = self._pets
+
+        try:
+            return self._pets[name]
+        except KeyError:
+            return default_value
+
     @cached_property("_cs_super_troops")
-    def super_troops(self) -> typing.List[Troop]:
+    def super_troops(self) -> List[Troop]:
         """List[:class:`Troop`]: A :class:`List` of the player's super troops.
 
         This will return super troops in the order found in the super troop boosting building, in game.
@@ -568,8 +599,8 @@ class Player(ClanMember):
 
         return list(sorted(self._super_troops, key=lambda t: order.get(t.name, 0)))
 
-    def get_troop(self, name: str, is_home_troop=None, default_value=None) -> typing.Optional[Troop]:
-        """Returns a troop with the given name.
+    def get_troop(self, name: str, is_home_troop=None, default_value=None) -> Optional[Troop]:
+        """Gets a troop with the given name.
 
         Parameters
         -----------
@@ -604,7 +635,7 @@ class Player(ClanMember):
             return default_value
 
     @cached_property("_cs_heroes")
-    def heroes(self) -> typing.List[Hero]:
+    def heroes(self) -> List[Hero]:
         """List[:class:`Hero`]: A :class:`List` of the player's :class:`Hero`.
 
         This will return heroes in the order found in the store and labatory in-game.
@@ -621,8 +652,8 @@ class Player(ClanMember):
         self._heroes = sorted_heroes
         return list(sorted_heroes.values())
 
-    def get_hero(self, name: str, default_value=None) -> typing.Optional[Hero]:
-        """Returns a hero with the given name.
+    def get_hero(self, name: str, default_value=None) -> Optional[Hero]:
+        """Gets the hero with the given name.
 
         Parameters
         -----------
@@ -634,7 +665,8 @@ class Player(ClanMember):
         Returns
         --------
         Optional[:class:`Hero`]
-            The returned hero or the ``default_value`` if not found, which defaults to ``None``..
+            The returned hero or the ``default_value`` if not found, which defaults to ``None``.
+
         """
         if not self._heroes:
             _ = self.heroes
@@ -645,7 +677,7 @@ class Player(ClanMember):
             return default_value
 
     @cached_property("_cs_spells")
-    def spells(self) -> typing.List[Spell]:
+    def spells(self) -> List[Spell]:
         """List[:class:`Spell`]: A :class:`List` of the player's :class:`Spell` ordered as they appear in-game.
 
         This will return spells in the order found in both spell factory and labatory in-game.
@@ -658,8 +690,8 @@ class Player(ClanMember):
                     dict_spells.values(),
                     key=lambda s: order.get(s.name, 0)))
 
-    def get_spell(self, name: str, default_value=None) -> typing.Optional[Spell]:
-        """Returns a spell with the given name.
+    def get_spell(self, name: str, default_value=None) -> Optional[Spell]:
+        """Gets the spell with the given name.
 
         Parameters
         -----------
